        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 18 <strong>control</strong><br>0,3,7,8,10,11,15,18,19,20,22,25,28,31,39,44,45,48';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>5,6,21,26,27,34,36,41,42,43,50';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>4,13,16,17,29,30,35,46,47,49';}
       if(rr==7 && cc==4){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 9 <br>1,2,9,12,14,23,32,38,40';}
       if(rr==7 && cc==5){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>24</strong> miembros: 3 <br>24,33,37';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 18 <strong>control</strong><br>0,3,7,8,10,11,15,18,19,20,22,25,28,31,39,44,45,48';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>5,6,21,26,27,34,36,41,42,43,50';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>4,13,16,17,29,30,35,46,47,49';}
       if(rr==34 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 9 <br>1,2,9,12,14,23,32,38,40';}
       if(rr==34 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>24</strong> miembros: 3 <br>24,33,37';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 18 <strong>control</strong><br>0,3,7,8,10,11,15,18,19,20,22,25,28,31,39,44,45,48';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>5,6,21,26,27,34,36,41,42,43,50';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>4,13,16,17,29,30,35,46,47,49';}
       if(rr==35 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 9 <br>1,2,9,12,14,23,32,38,40';}
       if(rr==35 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>24</strong> miembros: 3 <br>24,33,37';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 18 <strong>control</strong><br>0,3,7,8,10,11,15,18,19,20,22,25,28,31,39,44,45,48';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>5,6,21,26,27,34,36,41,42,43,50';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>4,13,16,17,29,30,35,46,47,49';}
       if(rr==36 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 9 <br>1,2,9,12,14,23,32,38,40';}
       if(rr==36 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>24</strong> miembros: 3 <br>24,33,37';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 18 <strong>control</strong><br>0,3,7,8,10,11,15,18,19,20,22,25,28,31,39,44,45,48';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>5,6,21,26,27,34,36,41,42,43,50';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>4,13,16,17,29,30,35,46,47,49';}
       if(rr==37 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 9 <br>1,2,9,12,14,23,32,38,40';}
       if(rr==37 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>24</strong> miembros: 3 <br>24,33,37';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 18 <strong>control</strong><br>0,3,7,8,10,11,15,18,19,20,22,25,28,31,39,44,45,48';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>5,6,21,26,27,34,36,41,42,43,50';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>4,13,16,17,29,30,35,46,47,49';}
       if(rr==38 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 9 <br>1,2,9,12,14,23,32,38,40';}
       if(rr==38 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>24</strong> miembros: 3 <br>24,33,37';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>28</strong> miembros: 18 <strong>control</strong><br>0,3,7,8,10,11,15,18,19,20,22,25,28,31,39,44,45,48';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>50</strong> miembros: 11 <br>5,6,21,26,27,34,36,41,42,43,50';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>3</strong> representante: <strong>29</strong> miembros: 10 <br>4,13,16,17,29,30,35,46,47,49';}
       if(rr==39 && cc==4){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>4</strong> representante: <strong>14</strong> miembros: 9 <br>1,2,9,12,14,23,32,38,40';}
       if(rr==39 && cc==5){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260629 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>5</strong> representante: <strong>24</strong> miembros: 3 <br>24,33,37';}
}
